@@ -1,3 +1,3 @@
 # -*- encoding: utf-8 -*-
 
-__author__ = 'gotlium'
+__author__ = "gotlium"
